"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../../cli");
const session_1 = require("../../session");
exports.command = 'audio-devices';
exports.desc = 'Fetch audio-devices';
exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};
exports.handler = (_) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    cli_1.default.stream.loading('Fetching audio devices');
    try {
        const client = new session_1.PegasusClient(cli_1.default.config.pegasusConfiguration);
        let captureDevice;
        let outputDevice;
        const audioDevices = yield client.get_audio_devices();
        if (audioDevices.inputs.length === 1) {
            cli_1.default.stream.success(`Found only 1 capture device named: ${audioDevices.inputs[0].info}`);
            cli_1.default.stream.hint('Using this device to capture sound');
            captureDevice = audioDevices.inputs[0];
        }
        else if (audioDevices.inputs.length > 0) {
            const response = yield cli_1.default.prompt.promptList('device', `Found ${audioDevices.inputs.length} interfaces to record sound.\n  Choose the one you want to use`, audioDevices.inputs.map(device => device.info));
            captureDevice = audioDevices.inputs.find(device => device.info === response['device']);
        }
        if (audioDevices.outputs.length === 1) {
            cli_1.default.stream.success(`Found only 1 output device named: ${audioDevices.outputs[0].info}`);
            cli_1.default.stream.hint('Using this device to capture sound');
            outputDevice = audioDevices.outputs[0];
        }
        else if (audioDevices.outputs.length > 0) {
            const response = yield cli_1.default.prompt.promptList('device', `Found ${audioDevices.outputs.length} interfaces to output sound.\n  Choose the one you want to use`, audioDevices.outputs.map(device => device.info));
            outputDevice = audioDevices.outputs.find(device => device.info === response['device']);
        }
        const input = {
            device_id: captureDevice ? captureDevice.card : 0,
            sub_device_id: captureDevice ? captureDevice.subdevice : 0,
            device_type: 'hw',
        };
        const output = {
            device_id: outputDevice ? outputDevice.card : 0,
            sub_device_id: outputDevice ? outputDevice.subdevice : 0,
            device_type: 'hw',
        };
        yield client.patch_audio_devices({ input, output });
        cli_1.default.stream.success();
    }
    catch (e) {
        cli_1.default.stream.error(`Failed to install platform: ${e.stack}`);
        process.exit();
    }
});
//# sourceMappingURL=audio-devices.js.map