"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../../cli");
const session_1 = require("../../session");
exports.command = 'connect';
exports.desc = 'Connect to Pegasus';
exports.handler = (_) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const hostnamePort = yield cli_1.default.prompt.promptQuestions([
        {
            name: 'hostname',
            type: 'input',
            default: cli_1.default.config.pegasusConfiguration.hostname !== undefined ? `${cli_1.default.config.pegasusConfiguration.hostname}` : 'raspberrypi.local',
            message: 'Enter hostname',
            validate: value => {
                if (value.length)
                    return true;
                return 'Hostname cannot be blank';
            },
        },
        {
            name: 'port',
            type: 'input',
            default: cli_1.default.config.pegasusConfiguration.port !== undefined ? cli_1.default.config.pegasusConfiguration.port : '8443',
            message: 'Enter port',
            validate: value => {
                if (value.length)
                    return true;
                return 'Port cannot be blank';
            },
        },
    ]);
    const hostname = hostnamePort['hostname'];
    const port = hostnamePort['port'];
    try {
        cli_1.default.stream.loading(`Connecting to ${hostname}`);
        const certificate = yield session_1.PegasusClient.get_certificate(hostname, port);
        cli_1.default.config.pegasusConfiguration.hostname = hostname;
        cli_1.default.config.pegasusConfiguration.port = port;
        cli_1.default.config.pegasusConfiguration.cert = certificate;
        yield cli_1.default.config.save();
        cli_1.default.stream.success();
    }
    catch (e) {
        cli_1.default.stream.stop();
        cli_1.default.stream.error('Failed to connect');
        cli_1.default.stream.error(e.message);
    }
    process.exit();
});
//# sourceMappingURL=connect.js.map