"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../../cli");
const session_1 = require("../../session");
const models_1 = require("../../models");
exports.command = 'login';
exports.desc = 'Login to Pegasus';
exports.handler = (_) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const responses = yield cli_1.default.prompt.promptQuestions([
        {
            name: 'username',
            type: 'username',
            message: 'Enter username',
            validate: value => {
                if (value.length)
                    return true;
                return 'Username cannot be blank';
            },
        },
        {
            name: 'password',
            type: 'password',
            message: 'Enter password',
            validate: value => {
                if (value.length)
                    return true;
                return 'Password cannot be blank';
            },
        },
    ]);
    const username = responses['username'];
    const password = responses['password'];
    try {
        cli_1.default.stream.loading('Logging in');
        cli_1.default.config.pegasusConfiguration.token = models_1.generateBase64Token(username, password);
        const client = new session_1.PegasusClient(cli_1.default.config.pegasusConfiguration);
        yield client.get_tasks();
        yield cli_1.default.config.save();
        cli_1.default.stream.success('Logged in');
    }
    catch (e) {
        cli_1.default.stream.stopAndClear();
        cli_1.default.stream.error('Failed to log in');
        cli_1.default.stream.error(e.message);
    }
    process.exit();
});
//# sourceMappingURL=login.js.map