"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const cli_1 = require("../../cli");
const session_1 = require("../../session");
exports.command = 'signup';
exports.desc = 'Signup as a new user to Pegasus';
exports.handler = (_) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const responses = yield cli_1.default.prompt.promptQuestions([
        {
            name: 'username',
            type: 'username',
            message: 'Enter username',
            validate: (value) => {
                if (value.length)
                    return true;
                return 'Username cannot be blank';
            },
        },
        {
            name: 'password',
            type: 'password',
            message: 'Enter password',
            validate: (value) => {
                if (value.length)
                    return true;
                return 'Password cannot be blank';
            },
        },
    ]);
    const username = responses['username'];
    const password = responses['password'];
    try {
        cli_1.default.stream.loading('Signing up');
        const client = new session_1.PegasusClient(cli_1.default.config.pegasusConfiguration);
        cli_1.default.config.pegasusConfiguration.token = yield client.signup(username, password);
        cli_1.default.stream.success(`Signed up as ${username}`);
        yield cli_1.default.config.save();
    }
    catch (e) {
        cli_1.default.stream.error('Failed to signup');
        cli_1.default.stream.error(e.message);
    }
    process.exit();
});
//# sourceMappingURL=signup.js.map