"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const process = require("process");
const chalk_1 = require("chalk");
const cli_1 = require("../../cli");
const session_1 = require("../../session");
const models_1 = require("../../models");
exports.command = 'update-platform';
exports.desc = 'Update Snips Platform';
exports.builder = {
    verbose: {
        demandOption: false,
        describe: 'Include remote logs',
        type: 'boolean',
        alias: 'v',
    },
};
exports.handler = (argv) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const verbose = JSON.parse(JSON.stringify(argv)).verbose;
    cli_1.default.stream.println('Installing Snips Platform components. This may take a few minutes...');
    try {
        const client = new session_1.PegasusClient(cli_1.default.config.pegasusConfiguration);
        const taskId = yield client.post_platform(models_1.PlatformAction.update);
        yield client.get_tasks_logs(taskId, (_, logs) => {
            if (verbose) {
                logs.forEach(log => {
                    if (log.source === models_1.TaskLogSource.Info) {
                        cli_1.default.stream.println(log.line);
                    }
                    else {
                        cli_1.default.stream.warning(log.line);
                    }
                });
            }
        });
    }
    catch (e) {
        cli_1.default.stream.error(`Failed to install platform: ${e.stack}`);
        process.exit();
    }
    cli_1.default.stream.success('Successfully installed the Snips Platform');
    cli_1.default.stream.hint(`You can now setup your audio with ${chalk_1.default.blue('sam setup audio')}`);
});
//# sourceMappingURL=update-platform.js.map