"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const wretch_1 = require("wretch");
const models_1 = require("../models");
const chalk_1 = require("chalk");
const utils_1 = require("../utils");
const fs_1 = require("fs");
const formData = require("form-data");
const https = require('https');
class PegasusClient {
    constructor(cfg) {
        if (!cfg.hostname && !cfg.port && !cfg.cert) {
            throw new Error('You need to login again with sam pegasus login');
        }
        this.wretch = wretch_1.default()
            .url(`https://${cfg.hostname}:${cfg.port}`)
            .options({ agent: new https.Agent({ ca: cfg.cert }) })
            .polyfills({
            fetch: require('node-fetch'),
            FormData: formData,
            URLSearchParams: require('url').URLSearchParams,
        })
            .catcher(401, _ => {
            throw new Error(`Address not found. Check if your device is connected to the network. Or connect again with ${chalk_1.default.blue('sam pegasus login')}`);
        });
        if (cfg.token !== undefined) {
            this.wretch.defaults({ headers: { Authorization: cfg.token } });
        }
    }
    static get_certificate(hostname, port) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return wretch_1.default()
                .url(`https://${hostname}:${port}`)
                .options({ agent: new https.Agent({ rejectUnauthorized: false }) })
                .polyfills({
                fetch: require('node-fetch'),
                FormData: formData,
                URLSearchParams: require('url').URLSearchParams,
            })
                .url('/pegasus/certificate')
                .get()
                .text();
        });
    }
    put_assistant_from_console(assistantId, consoleToken, cleanPreviousActions, installActions, installDir) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let form;
            if (installDir !== undefined) {
                form = {
                    assistant_id: assistantId,
                    console_token: consoleToken,
                    install_dir: installDir,
                    clean_previous_actions: cleanPreviousActions.toString(),
                    install_actions: installActions.toString(),
                };
            }
            else {
                form = {
                    assistant_id: assistantId,
                    console_token: consoleToken,
                    clean_previous_actions: cleanPreviousActions.toString(),
                    install_actions: installActions.toString(),
                };
            }
            return this.wretch
                .url('/pegasus/assistant')
                .formData(form)
                .put()
                .json(j => new models_1.TaskCreated(j).taskid);
        });
    }
    put_assistant_zip(assistantZipPath, installActions, cleanPreviousActions, installDir) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let formData;
            if (installDir !== undefined) {
                formData = {
                    assistant_zip: fs_1.readFileSync(assistantZipPath),
                    install_dir: installDir,
                    clean_previous_actions: cleanPreviousActions.toString(),
                    install_actions: installActions.toString(),
                };
            }
            else {
                formData = {
                    assistant_zip: fs_1.readFileSync(assistantZipPath),
                    clean_previous_actions: cleanPreviousActions.toString(),
                    install_actions: installActions.toString(),
                };
            }
            return this.wretch
                .url('/pegasus/assistant')
                .formData(formData)
                .put()
                .json(j => new models_1.TaskCreated(j).taskid);
        });
    }
    get_assistant_infos() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/assistant/infos')
                .get()
                .json(json => console.log(json));
        });
    }
    get_audio_devices() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/audio-devices')
                .get()
                .json(json => new models_1.AudioDevices(json));
        });
    }
    patch_audio_devices(audioDevices) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/audio-devices')
                .json({ input: audioDevices.input, output: audioDevices.output })
                .patch()
                .text();
        });
    }
    get_platform() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
        });
    }
    post_platform(platformAction) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/platform')
                .json({ action: platformAction.toString() })
                .post()
                .json(j => new models_1.TaskCreated(j).taskid);
        });
    }
    patch_platform_config(toml) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/platform/config')
                .json({ toml })
                .patch();
        });
    }
    get_platform_component(component) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url(`/pegasus/platform/${component}`)
                .get()
                .json(json => new models_1.Component(json));
        });
    }
    get_tasks() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/tasks')
                .get()
                .json(json => new models_1.Tasks(json).tasks);
        });
    }
    get_task(id) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url(`/pegasus/tasks/${id}`)
                .get()
                .json(json => new models_1.Task(json));
        });
    }
    signup(login, password) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/user')
                .json({ login, password })
                .post()
                .res()
                .then((response) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                if (response.status === 201) {
                    const token = models_1.generateBase64Token(login, password);
                    this.wretch.defaults({ headers: { Authorization: token } });
                    return token;
                }
                throw new Error(`Response status isn't valid ${response.status} ${response.statusText}`);
            }));
        });
    }
    patch_user(login, password) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/user')
                .json({ login, password })
                .patch();
        });
    }
    get_version() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.wretch
                .url('/pegasus/version')
                .get()
                .text();
        });
    }
    get_tasks_logs(taskid, callback) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                try {
                    let task;
                    const logs = [];
                    do {
                        yield utils_1.timeout(1000);
                        task = yield this.get_task(taskid);
                        let newLogs = [];
                        if (task.logs && task.logs.length > 0) {
                            newLogs = task.logs.slice(logs.length);
                            newLogs.forEach(l => logs.push(l));
                        }
                        callback(task, newLogs);
                    } while (task.status === models_1.TaskStatus.Running || task.status === models_1.TaskStatus.Queued);
                    resolve(task);
                }
                catch (e) {
                    reject(e);
                }
            }));
        });
    }
}
exports.PegasusClient = PegasusClient;
//# sourceMappingURL=pegasusClient.js.map